@@ -503,11 +503,21 @@ def test_pmath_in_utility():
 		'nonmotorized_time': -11.789244777056298,
 		'totcost': -20.19350165272386,
 	}
-	assert dict(m0.pf['t stat']) == pytest.approx(t, rel=1e-5)
-	assert dict(m1.pf['t stat']) == pytest.approx(t, rel=1e-5)
+	assert dict(m0.pf['t_stat']) == pytest.approx(t, rel=1e-5)
+	assert dict(m1.pf['t_stat']) == pytest.approx(t, rel=1e-5)
 
 	assert (m0.get_value(P.motorized_ivtt) * 60) / (m0.get_value(P.totcost) * 100) == pytest.approx(0.3191492801963062)
 	assert m0.get_value( (P.motorized_ivtt * 60) / (P.totcost * 100) ) == pytest.approx(0.3191492801963062)
 	assert (m1.get_value(P.motorized_ivtt) * 60) / (m1.get_value(P.totcost) * 100) == pytest.approx(0.3191492801963062)
 	assert m1.get_value( (P.motorized_ivtt * 60) / (P.totcost * 100) ) == pytest.approx(0.3191492801963062)
 
+def test_linear_function_iadd():
+	# Test inplace add on unattached LinearFunction_C
+	lf = P.tottime * X.tottime + P.totcost * X.totcost
+	lf += X("totcost*tottime") * P("fake")
+	assert lf == P.tottime * X.tottime + P.totcost * X.totcost + X("totcost*tottime") * P("fake")
+	# Test inplace add on attached LinearFunction_C
+	m = larch.Model(utility_ca=P.tottime * X.tottime + P.totcost * X.totcost)
+	m.utility_ca += X("totcost*tottime") * P("fake")
+	xx = P.tottime * X.tottime + P.totcost * X.totcost + X("totcost*tottime") * P("fake")
+	assert m.utility_ca == xx
